==> harlequin-0.0.27-py3-none-any.whl: harlequin/tui/components/help_screen.md <==
### General Bindings

- ctrl+q: Quit Harlequin
- F1: Show this screen.
- F2: Focus on the Query Editor.
- F5: Focus on the Results Viewer.
- F6: Focus on the Data Catalog.
- F9, ctrl+b: Toggle the sidebar.
- F10: Toggle full screen mode for the current widget.
- ctrl+e: Write the returned data to a CSV, Parquet, or JSON file.

### Query Editor Bindings

#### Actions
- F4: Format the query.
- ctrl+enter: Run the query.
- ctrl+o: Open a text file in the Query Editor.
- ctrl+s: Save the contents of the Query Editor to a file.
- ctrl+n: Create a new buffer (editor tab).
- ctrl+w: Close the current buffer (editor tab).
- ctrl+k: View the next buffer (editor tab).

#### Editing Text
- ctrl+a: Select all, move the cursor to the end of the query.
- ctrl+x: Cut selected text.
- ctrl+c: Copy selected text.
- ctrl+v, ctrl+u: Paste selected text.
- ctrl+z: Undo.
- ctrl+y: Redo.
- ctrl+/, ctrl+_: Toggle comments on selected line(s).
- tab: Insert spaces at cursor to move the cursor to the next tab stop, or indent the selected line(s) to the next tab stop.
- shift+tab: Dedent the selected line(s) to the next tab stop.
- shift+delete: Delete the current line.

#### Moving the Cursor
- up,down,left,right: Move the cursor one position.
- home: Move the cursor to the start of the line.
- end: Move the cursor to the end of the line.
- ctrl+home: Move the cursor to the start of the query.
- ctrl+end: Move the cursor to the end of the query.
- PgUp: Move the cursor up one screen.
- PgDn: Move the cursor down one screen.
- ctrl+up: Scroll up one line.
- ctrl+down: Scroll up one line.
- ctrl+left: Move the cursor to the start of the current token.
- ctrl+right: Move the cursor to the end of the current token.
- shift+[up,down,left,right,home,end,PgUp,PgDn,ctrl+left,ctrl+right]: Select text while moving the cursor.

### Results Viewer Bindings

#### Switching Tabs
- j: Switch to the previous tab.
- k: Switch to the next tab.
#### Moving the Cursor
- up,down,left,right: Move the cursor one cell.
- home: Move the cursor to the top of the current column.
- end: Move the cursor to the bottom of the current column.
- PgUp: Move the cursor up one screen.
- PgDn: Move the cursor down one screen.

==> harlequin-0.0.28-py3-none-any.whl: harlequin/tui/components/help_screen.md <==
### General Bindings

- ctrl+q: Quit Harlequin
- F1: Show this screen.
- F2: Focus on the Query Editor.
- F5: Focus on the Results Viewer.
- F6: Focus on the Data Catalog.
- F9, ctrl+b: Toggle the sidebar.
- F10: Toggle full screen mode for the current widget.
- ctrl+e: Write the returned data to a CSV, Parquet, or JSON file.

### Query Editor Bindings

#### Actions
- F4: Format the query.
- ctrl+enter, ctrl+j: Run the query.
- ctrl+o: Open a text file in the Query Editor.
- ctrl+s: Save the contents of the Query Editor to a file.
- ctrl+n: Create a new buffer (editor tab).
- ctrl+w: Close the current buffer (editor tab).
- ctrl+k: View the next buffer (editor tab).

#### Editing Text
- ctrl+a: Select all, move the cursor to the end of the query.
- ctrl+x: Cut selected text.
- ctrl+c: Copy selected text.
- ctrl+v, ctrl+u: Paste selected text.
- ctrl+z: Undo.
- ctrl+y: Redo.
- ctrl+/, ctrl+_: Toggle comments on selected line(s).
- tab: Insert spaces at cursor to move the cursor to the next tab stop, or indent the selected line(s) to the next tab stop.
- shift+tab: Dedent the selected line(s) to the next tab stop.
- shift+delete: Delete the current line.

#### Moving the Cursor
- up,down,left,right: Move the cursor one position.
- home: Move the cursor to the start of the line.
- end: Move the cursor to the end of the line.
- ctrl+home: Move the cursor to the start of the query.
- ctrl+end: Move the cursor to the end of the query.
- PgUp: Move the cursor up one screen.
- PgDn: Move the cursor down one screen.
- ctrl+up: Scroll up one line.
- ctrl+down: Scroll down one line.
- ctrl+left: Move the cursor to the start of the current token.
- ctrl+right: Move the cursor to the end of the current token.
- shift+[any]: Select text while moving the cursor.

### Results Viewer Bindings

#### Switching Tabs
- j: Switch to the previous tab.
- k: Switch to the next tab.
#### Moving the Cursor
- up,down,left,right: Move the cursor one cell.
- home: Move the cursor to the top of the current column.
- end: Move the cursor to the bottom of the current column.
- PgUp: Move the cursor up one screen.
- PgDn: Move the cursor down one screen.
